@@ -1,30 +1,5 @@
-/* libmpdclient
-   (c) 2003-2019 The Music Player Daemon Project
-   This project's homepage is: http://www.musicpd.org
-
-   Redistribution and use in source and binary forms, with or without
-   modification, are permitted provided that the following conditions
-   are met:
-
-   - Redistributions of source code must retain the above copyright
-   notice, this list of conditions and the following disclaimer.
-
-   - Redistributions in binary form must reproduce the above copyright
-   notice, this list of conditions and the following disclaimer in the
-   documentation and/or other materials provided with the distribution.
-
-   THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
-   ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
-   LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
-   A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE FOUNDATION OR
-   CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
-   EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
-   PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
-   PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
-   LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
-   NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
-   SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-*/
+// SPDX-License-Identifier: BSD-2-Clause
+// Copyright The Music Player Daemon Project
 
 /*! \file
  * \brief MPD client library
@@ -38,6 +13,7 @@
 #define MPD_PLAYER_H
 
 #include "compiler.h"
+#include "status.h"
 
 #include <stdbool.h>
 
@@ -129,7 +105,7 @@ mpd_run_play_pos(struct mpd_connection *connection, unsigned song_pos);
  * Starts playing the specified song from the beginning.
  *
  * @param connection the connection to MPD
- * @param id the id of the song
+ * @param song_id the id of the song
  * @return true on success, false on error
  */
 bool
@@ -269,7 +245,7 @@ mpd_run_seek_pos(struct mpd_connection *connection,
  * Seeks to the position t (in seconds) of song id song_id.
  *
  * @param connection the connection to MPD
- * @param id the id of the song
+ * @param song_id the id of the song
  * @param t the position within the song, in seconds
  * @return true on success, false on error
  */
@@ -331,6 +307,9 @@ mpd_send_seek_current(struct mpd_connection *connection,
  * Shortcut for mpd_send_seek_current() and mpd_response_finish().
  *
  * @param connection the connection to MPD
+ * @param t the new position (in seconds)
+ * @param relative true to seek relative to the current position and
+ * false to seek to an absolute time stamp within the song
  * @return true on success, false on error
  *
  * @since MPD 0.17, libmpdclient 2.15
@@ -383,8 +362,46 @@ mpd_send_random(struct mpd_connection *connection, bool mode);
 bool
 mpd_run_random(struct mpd_connection *connection, bool mode);
 
+/**
+ * Sets single state for the playlist.
+ * If state is #MPD_SINGLE_ON, MPD enables single mode: playback is stopped
+ * after current song, or song is repeated if the repeat mode is enabled.
+ *
+ * If state is #MPD_SINGLE_OFF, MPD disables single mode: if random mode is
+ * enabled, the playlist order is shuffled after it is played completely.
+ *
+ * If state is #MPD_SINGLE_ONESHOT, MPD enables single mode temporarily: single
+ * mode is disabled (#MPD_SINGLE_OFF) after a song has been played and there is
+ * another song in the current playlist.
+ *
+ * @param connection the connection to MPD
+ * @param state the desired single mode state
+ * @return true on success, false on error or state is #MPD_SINGLE_UNKNOWN
+ *
+ * @since MPD 0.21, libmpdclient 2.18.
+ */
+bool
+mpd_send_single_state(struct mpd_connection *connection,
+		      enum mpd_single_state state);
+
+/**
+ * Shortcut for mpd_send_single_state() and mpd_response_finish().
+ *
+ * @param connection the connection to MPD
+ * @param state the desired single mode state
+ * @return true on success, false on error or state is #MPD_SINGLE_UNKNOWN
+ *
+ * @since MPD 0.21, libmpdclient 2.18.
+ */
+bool
+mpd_run_single_state(struct mpd_connection *connection,
+		      enum mpd_single_state state);
+
 /**
  * Sets single mode on/off for the playlist.
+ * This function does not support the 'oneshot' state for single mode: use
+ * mpd_send_single_state() instead.
+ *
  * If mode is true, MPD enables single mode: playback is stopped after current
  * song, or song is repeated if the repeat mode is enabled.
  *
@@ -417,6 +434,9 @@ mpd_run_single(struct mpd_connection *connection, bool mode);
  * If mode is true, MPD enables consume mode: each song played is removed from
  * the playlist.
  *
+ * This function does not support the 'oneshot' state for consume mode: use
+ * mpd_send_consume_state() instead.
+ *
  * If mode is false, MPD disables consume mode.
  *
  * @param connection the connection to MPD
@@ -440,6 +460,37 @@ mpd_send_consume(struct mpd_connection *connection, bool mode);
 bool
 mpd_run_consume(struct mpd_connection *connection, bool mode);
 
+/**
+ * Sets consume state for the playlist.
+ * If state is #MPD_CONSUME_ON, MPD enables consume mode: each song played is removed from
+ * the playlist.
+ *
+ * If state is #MPD_CONSUME_OFF, MPD disables consume mode.
+ *
+ * If state is #MPD_CONSUME_ONESHOT, MPD enables consume mode temporarily: consume
+ * mode is disabled (#MPD_CONSUME_OFF) after a song has been played.
+ *
+ * @param connection the connection to MPD
+ * @param state the desired single mode state
+ * @return true on success, false on error or state is #MPD_SINGLE_UNKNOWN
+ *
+ * @since MPD 0.24, libmpdclient 2.21.
+ */
+bool
+mpd_send_consume_state(struct mpd_connection *connection, enum mpd_consume_state state);
+
+/**
+ * Shortcut for mpd_send_consume_state() and mpd_response_finish().
+ *
+ * @param connection the connection to MPD
+ * @param state the desired single mode state
+ * @return true on success, false on error or state is #MPD_SINGLE_UNKNOWN
+ *
+ * @since MPD 0.24, libmpdclient 2.21.
+ */
+bool
+mpd_run_consume_state(struct mpd_connection *connection, enum mpd_consume_state state);
+
 /**
  * Sets crossfading of seconds between songs on for the playlist.
  * Crossfading only happens when the songs audio format are the same.
